@@ -324,12 +324,7 @@ class TreeHandler(GenericHandler):
                     # taxon only
                     sub = taxon
                 sub = "%s%s%s" % (found['start'], sub, found['end'])
-                if found['match'] not in tree:
-                    raise ValueError(
-                        "Expected match for %s not in tree" % found['match']
-                    )
                 tree = tree.replace(found['match'], sub)
-
         return tree
 
     def write(self):
@@ -346,7 +341,9 @@ class TreeHandler(GenericHandler):
             for index in sorted([int(k) for k in self.translators.keys()]):
                 out.append("\t%d %s," % (index, self.translators[str(index)]))
             # handle last taxa label in translate block
-            out[-1] = out[-1].replace(',', ';')
+            out[-1] = out[-1].replace(',', '')
+            # work around bug https://github.com/CompEvol/beast2/issues/713
+            out.append(';')
         for tree in self.trees:
             out.append("\t" + tree)
         out.append('end;\n')
@@ -421,6 +418,9 @@ class DataHandler(GenericHandler):
     def hash(self):
         return md5(pickle.dumps(self.matrix)).hexdigest()
     
+    def is_missing_or_gap(self, state):
+        return True if state in ('-', '?') else False
+    
     def parse_format_line(self, data):
         """
         Parses a format line, and returns a dictionary of tokens
@@ -436,10 +436,9 @@ class DataHandler(GenericHandler):
             line = self._format_line_pattern.findall(data)[0]
         except IndexError:
             return None
-
-        line = line.strip(';')
+        
         line = line.lower()
-
+        line = line.replace(" =", "=").replace("= ", "=")  # standardise
         for chunk in WHITESPACE_PATTERN.split(line):
             try:
                 key, value = chunk.split("=")
@@ -472,12 +471,11 @@ class DataHandler(GenericHandler):
         :raises NexusFormatException: If data matrix contains incomplete
             multistate values
         """
-        sites = [s for s in sites if s != ' ']
+        remove_values = [' ', ';']
+        sites = [s for s in sites if s not in remove_values]
         if '(' not in sites:
-            import sys; sys.stdout.write("FAST"); sys.stdout.flush()
             return sites
         else:
-            import sys; sys.stdout.write("SLOW"); sys.stdout.flush()
             multistate = False
             out = []
             # Slow reader for multistate
@@ -555,12 +553,12 @@ class DataHandler(GenericHandler):
                 # try for ntaxa
                 try:
                     _dim_taxa = int(NTAX_PATTERN.findall(line)[0])
-                except IndexError:
+                except IndexError:  # pragma: no cover
                     pass
                 # and nchar
                 try:
                     _dim_chars = int(NCHAR_PATTERN.findall(line)[0])
-                except IndexError:
+                except IndexError:  # pragma: no cover
                     pass
 
             # handle MESQUITE attributes
@@ -644,7 +642,9 @@ class DataHandler(GenericHandler):
                     continue
                 else:
                     if key == 'symbols':
-                        value = '"%s"' % "".join(sorted(self.symbols))
+                        value = '"%s"' % "".join(sorted([
+                            s for s in self.symbols if not self.is_missing_or_gap(s)
+                        ]))
                     fstring.append("%s=%s" % (key, value))
             return " ".join(fstring) + ";"
         
@@ -654,16 +654,21 @@ class DataHandler(GenericHandler):
             out.append("\t%s" % att)
         out.append('\tdimensions ntax=%d nchar=%d;' % (self.ntaxa, self.nchar))
         out.append(_make_format_line(self))
+        # handle char block
+        if len(self.charlabels):
+            out.append('\tcharstatelabels')
+            max_id = max(self.charlabels)
+            for char_id in sorted(self.charlabels):
+                out.append('\t\t%d %s%s' % (
+                    char_id + 1,  # zero-indexing
+                    self.charlabels[char_id],
+                    ',' if char_id < max_id else ''
+                ))
+            out.append('\t;')
         out.append("matrix")
         max_taxon_len = max([len(_) for _ in self.matrix])
         for taxon in sorted(self.matrix):
-            sites = self.matrix[taxon]
-            if len(sites) != self.nchar:
-                raise NexusFormatException(
-                    "Number of characters is wrong - expecting %d, got %d" %
-                    (self.nchar, len(sites))
-                )
-            out.append("%s %s" % (taxon.ljust(max_taxon_len), ''.join(sites)))
+            out.append("%s %s" % (taxon.ljust(max_taxon_len), ''.join(self.matrix[taxon])))
         out.append(" ;")
         out.append("end;")
         return "\n".join(out)
@@ -673,6 +678,10 @@ class DataHandler(GenericHandler):
             (self.nchar, self.ntaxa)
 
 
+class CharacterHandler(DataHandler):
+    pass
+
+
 class NexusReader(object):
     """A nexus reader"""
     def __init__(self, filename=None, debug=False):
@@ -681,7 +690,7 @@ class NexusReader(object):
         self.raw_blocks = {}
         self.handlers = {
             'data': DataHandler,
-            'characters': DataHandler,
+            'characters': CharacterHandler,
             'trees': TreeHandler,
             'taxa': TaxaHandler,
         }
@@ -691,12 +700,15 @@ class NexusReader(object):
     def _do_blocks(self):
         """Iterates over all nexus blocks and parses them appropriately"""
         for block, data in self.raw_blocks.items():
-            if block == 'characters':
-                block = 'data'  # override
             self.blocks[block] = self.handlers.get(block, GenericHandler)()
             self.blocks[block].parse(data)
+        
+        if self.blocks.get('characters') and not self.blocks.get('data'):
+            self.blocks['data'] = self.blocks['characters']
+        
+        for block in self.blocks:
             setattr(self, block, self.blocks[block])
-
+        
     def read_file(self, filename):
         """
         Loads and Parses a Nexus File
