@@ -9,6 +9,7 @@ from nexus.tools.sites import count_site_values
 from nexus.tools.sites import new_nexus_without_sites
 from nexus.tools.sites import tally_by_site
 from nexus.tools.sites import tally_by_taxon
+from nexus.tools.sites import count_binary_set_size
 
 __all__ = [
     "check_for_valid_NexusReader",
@@ -22,6 +23,7 @@ __all__ = [
     "new_nexus_without_sites",
     "tally_by_site",
     "tally_by_taxon",
+    "count_binary_set_size",
     "check_zeros",
     "remove_zeros",
 ]
\ No newline at end of file
